@@ -116,26 +116,3 @@ def var_exists(context, name):
             if name in d:
                 return True
     return False
-
-
-class TryIncludeNode(template.Node):
-    """
-    A Node that instantiates an IncludeNode but wraps its render() in a
-    try/except in case the template doesn't exist.
-    """
-    def __init__(self, parser, token):
-        self.include_node = do_include(parser, token)
-
-    def render(self, context):
-        try:
-            return self.include_node.render(context)
-        except template.TemplateDoesNotExist:
-            return ''
-
-
-@register.tag('try_include')
-def try_include(parser, token):
-    """
-    Include the specified template but only if it exists.
-    """
-    return TryIncludeNode(parser, token)
