@@ -12,9 +12,9 @@ router.register(r"views", api.ViewAPI, basename="view")
 urlpatterns = [
     path("api/dm/", include((router.urls, app_name), namespace="api")),
 
-    path("api/dm/columns/", api.ProjectColumnsAPI.as_view()),
-    path("api/dm/project/", api.ProjectStateAPI.as_view()),
-    path("api/dm/actions/", api.ProjectActionsAPI.as_view()),
+    path("api/dm/columns/", api.ProjectColumnsAPI.as_view(), name='dm-columns'),
+    path("api/dm/project/", api.ProjectStateAPI.as_view(), name='dm-project'),
+    path("api/dm/actions/", api.ProjectActionsAPI.as_view(), name='dm-actions'),
     # path("api/dm/tasks/", api.TaskListAPI.as_view()),
     # path("api/dm/tasks/<int:pk>", api.TaskAPI.as_view()),
 
