@@ -4,6 +4,7 @@ import os
 
 from rest_framework.exceptions import ValidationError
 from rest_framework import serializers
+from rest_framework.mixins import UpdateModelMixin
 from botocore.exceptions import ParamValidationError, ClientError
 from io_storages.serializers import ImportStorageSerializer, ExportStorageSerializer
 from io_storages.s3.models import S3ImportStorage, S3ExportStorage
@@ -17,12 +18,23 @@ class S3ImportStorageSerializer(ImportStorageSerializer):
         model = S3ImportStorage
         fields = '__all__'
 
+    def to_representation(self, instance):
+        result = super().to_representation(instance)
+        result.pop('aws_access_key_id')
+        result.pop('aws_secret_access_key')
+        return result
+
     def validate(self, data):
         data = super(S3ImportStorageSerializer, self).validate(data)
         if not data.get('bucket', None):
             return data
-        
-        storage = S3ImportStorage(**data)
+
+        storage = self.instance
+        if storage:
+            for key, value in data.items():
+                setattr(storage, key, value)
+        else:
+            storage = S3ImportStorage(**data)
         try:
             storage.validate_connection()
         except ParamValidationError:
@@ -40,6 +52,12 @@ class S3ImportStorageSerializer(ImportStorageSerializer):
 class S3ExportStorageSerializer(ExportStorageSerializer):
     type = serializers.ReadOnlyField(default=os.path.basename(os.path.dirname(__file__)))
 
+    def to_representation(self, instance):
+        result = super().to_representation(instance)
+        result.pop('aws_access_key_id')
+        result.pop('aws_secret_access_key')
+        return result
+
     class Meta:
         model = S3ExportStorage
         fields = '__all__'
