@@ -13,13 +13,11 @@ app_name = 'storages'
 
 # IO Storages CRUD
 _api_urlpatterns = [
-
     # All storages
     path('', AllImportStorageListAPI.as_view(), name='storage-list'),
     path('export', AllExportStorageListAPI.as_view(), name='export-storage-list'),
     path('types', AllImportStorageTypesAPI.as_view(), name='storage-types'),
     path('export/types', AllExportStorageTypesAPI.as_view(), name='export-storage-types'),
-
     # Amazon S3
     path('s3', S3ImportStorageListAPI.as_view(), name='storage-s3-list'),
     path('s3/<int:pk>', S3ImportStorageDetailAPI.as_view(), name='storage-s3-detail'),
@@ -28,9 +26,9 @@ _api_urlpatterns = [
     path('s3/form', S3ImportStorageFormLayoutAPI.as_view(), name='storage-s3-form'),
     path('export/s3', S3ExportStorageListAPI.as_view(), name='export-storage-s3-list'),
     path('export/s3/<int:pk>', S3ExportStorageDetailAPI.as_view(), name='export-storage-s3-detail'),
+    path('export/s3/<int:pk>/sync', S3ExportStorageSyncAPI.as_view(), name='export-storage-s3-sync'),
     path('export/s3/validate', S3ExportStorageValidateAPI.as_view(), name='export-storage-s3-validate'),
     path('export/s3/form', S3ExportStorageFormLayoutAPI.as_view(), name='export-storage-s3-form'),
-
     # Microsoft Azure
     path('azure', AzureBlobImportStorageListAPI.as_view(), name='storage-azure-list'),
     path('azure/<int:pk>', AzureBlobImportStorageDetailAPI.as_view(), name='storage-azure-detail'),
@@ -39,9 +37,9 @@ _api_urlpatterns = [
     path('azure/form', AzureBlobImportStorageFormLayoutAPI.as_view(), name='storage-azure-form'),
     path('export/azure', AzureBlobExportStorageListAPI.as_view(), name='export-storage-azure-list'),
     path('export/azure/<int:pk>', AzureBlobExportStorageDetailAPI.as_view(), name='export-storage-azure-detail'),
+    path('export/azure/<int:pk>/sync', AzureBlobExportStorageSyncAPI.as_view(), name='export-storage-azure-sync'),
     path('export/azure/validate', AzureBlobExportStorageValidateAPI.as_view(), name='export-storage-azure-validate'),
     path('export/azure/form', AzureBlobExportStorageFormLayoutAPI.as_view(), name='export-storage-azure-form'),
-
     # Google Cloud Storage
     path('gcs', GCSImportStorageListAPI.as_view(), name='storage-gcs-list'),
     path('gcs/<int:pk>', GCSImportStorageDetailAPI.as_view(), name='storage-gcs-detail'),
@@ -50,9 +48,9 @@ _api_urlpatterns = [
     path('gcs/form', GCSImportStorageFormLayoutAPI.as_view(), name='storage-gcs-form'),
     path('export/gcs', GCSExportStorageListAPI.as_view(), name='export-storage-gcs-list'),
     path('export/gcs/<int:pk>', GCSExportStorageDetailAPI.as_view(), name='export-storage-gcs-detail'),
+    path('export/gcs/<int:pk>/sync', GCSExportStorageSyncAPI.as_view(), name='export-storage-gcs-sync'),
     path('export/gcs/validate', GCSExportStorageValidateAPI.as_view(), name='export-storage-gcs-validate'),
     path('export/gcs/form', GCSExportStorageFormLayoutAPI.as_view(), name='export-storage-gcs-form'),
-
     # Redis DB
     path('redis', RedisImportStorageListAPI.as_view(), name='storage-redis-list'),
     path('redis/<int:pk>', RedisImportStorageDetailAPI.as_view(), name='storage-redis-detail'),
@@ -61,6 +59,7 @@ _api_urlpatterns = [
     path('redis/form', RedisImportStorageFormLayoutAPI.as_view(), name='storage-redis-form'),
     path('export/redis', RedisExportStorageListAPI.as_view(), name='export-storage-redis-list'),
     path('export/redis/<int:pk>', RedisExportStorageDetailAPI.as_view(), name='export-storage-redis-detail'),
+    path('export/redis/<int:pk>/sync', RedisExportStorageSyncAPI.as_view(), name='export-storage-redis-sync'),
     path('export/redis/validate', RedisExportStorageValidateAPI.as_view(), name='export-storage-redis-validate'),
     path('export/redis/form', RedisExportStorageFormLayoutAPI.as_view(), name='export-storage-redis-form'),
 ]
@@ -73,9 +72,26 @@ if settings.ENABLE_LOCAL_FILES_STORAGE:
         path('localfiles/validate', LocalFilesImportStorageValidateAPI.as_view(), name='storage-localfiles-validate'),
         path('localfiles/form', LocalFilesImportStorageFormLayoutAPI.as_view(), name='storage-localfiles-form'),
         path('export/localfiles', LocalFilesExportStorageListAPI.as_view(), name='export-storage-localfiles-list'),
-        path('export/localfiles/<int:pk>', LocalFilesExportStorageDetailAPI.as_view(), name='export-storage-localfiles-detail'),
-        path('export/localfiles/validate', LocalFilesExportStorageValidateAPI.as_view(), name='export-storage-localfiles-validate'),
-        path('export/localfiles/form', LocalFilesExportStorageFormLayoutAPI.as_view(), name='export-storage-localfiles-form'),
+        path(
+            'export/localfiles/<int:pk>',
+            LocalFilesExportStorageDetailAPI.as_view(),
+            name='export-storage-localfiles-detail',
+        ),
+        path(
+            'export/localfiles/<int:pk>/sync',
+            LocalFilesExportStorageSyncAPI.as_view(),
+            name='export-storage-localfiles-sync',
+        ),
+        path(
+            'export/localfiles/validate',
+            LocalFilesExportStorageValidateAPI.as_view(),
+            name='export-storage-localfiles-validate',
+        ),
+        path(
+            'export/localfiles/form',
+            LocalFilesExportStorageFormLayoutAPI.as_view(),
+            name='export-storage-localfiles-form',
+        ),
     ]
 
 urlpatterns = [
