@@ -12,13 +12,12 @@ from rest_framework.parsers import FormParser, JSONParser, MultiPartParser
 from rest_framework.views import APIView
 from rest_framework.response import Response
 
+from core.feature_flags import flag_set
 from core.permissions import all_permissions, ViewClassPermission
 from core.utils.common import get_object_with_check_and_log
 from projects.models import Project, Task
 from ml.serializers import MLBackendSerializer, MLInteractiveAnnotatingRequest
 from ml.models import MLBackend
-from ml.api_connector import MLApi
-from core.utils.common import bool_from_request
 
 logger = logging.getLogger(__name__)
 
@@ -248,9 +247,42 @@ class MLBackendInteractiveAnnotating(APIView):
         task = get_object_with_check_and_log(request, Task, pk=validated_data['task'], project=ml_backend.project)
         context = validated_data.get('context')
 
+        if flag_set('ff_back_dev_2362_project_credentials_060722_short', request.user):
+            context['project_credentials_login'] = task.project.task_data_login
+            context['project_credentials_password'] = task.project.task_data_password
+
         result = ml_backend.interactive_annotating(task, context, user=request.user)
 
         return Response(
             result,
             status=status.HTTP_200_OK,
         )
+
+
+@method_decorator(
+    name='get',
+    decorator=swagger_auto_schema(
+        tags=['Machine Learning'],
+        operation_summary='Get model versions',
+        operation_description='Get available versions of the model.',
+        responses={"200": "List of available versions."},
+    ),
+)
+class MLBackendVersionsAPI(generics.RetrieveAPIView):
+
+    permission_required = all_permissions.projects_change
+
+    def get(self, request, *args, **kwargs):
+        ml_backend = get_object_with_check_and_log(request, MLBackend, pk=self.kwargs['pk'])
+        self.check_object_permissions(self.request, ml_backend)
+        versions_response = ml_backend.get_versions()
+        if versions_response.status_code == 200:
+            result = {'versions': versions_response.response.get("versions", [])}
+            return Response(data=result, status=200)
+        elif versions_response.status_code == 404:
+            result = {'versions': [ml_backend.model_version], 'message': 'Upgrade your ML backend version to latest.'}
+            return Response(data=result, status=200)
+        else:
+            result = {'error': str(versions_response.error_message)}
+            status_code = versions_response.status_code if versions_response.status_code > 0 else 500
+            return Response(data=result, status=status_code)
