@@ -223,11 +223,16 @@ class BaseTaskSerializerBulk(serializers.ListSerializer):
             elif isinstance(completed_by, dict):
                 if 'email' not in completed_by:
                     raise ValidationError(f"It's expected to have 'email' field in 'completed_by' data in annotations")
+
                 email = completed_by['email']
                 if email not in members_email_to_id:
-                    raise ValidationError(f"Unknown annotator's email {email}")
-                # overwrite an actual member ID
-                annotation['completed_by_id'] = members_email_to_id[email]
+                    if settings.ALLOW_IMPORT_TASKS_WITH_UNKNOWN_EMAILS:
+                        annotation['completed_by_id'] = default_user.id
+                    else:
+                        raise ValidationError(f"Unknown annotator's email {email}")
+                else:
+                    # overwrite an actual member ID
+                    annotation['completed_by_id'] = members_email_to_id[email]
 
             # old style annotators specification - try to find them by ID
             elif isinstance(completed_by, int) and completed_by in members_ids:
@@ -323,6 +328,7 @@ class BaseTaskSerializerBulk(serializers.ListSerializer):
 
                     body = {
                         'task': self.db_tasks[i],
+                        'project': self.project,
                         'ground_truth': ground_truth,
                         'was_cancelled': was_cancelled,
                         'completed_by_id': annotation['completed_by_id'],
@@ -384,12 +390,17 @@ class BaseTaskSerializerBulk(serializers.ListSerializer):
                 self.project.save()
 
         self.post_process_annotations(user, self.db_annotations, 'imported')
+        self.post_process_tasks(self.project.id, [t.id for t in self.db_tasks])
         return db_tasks
 
     @staticmethod
     def post_process_annotations(user, db_annotations, action):
         pass
 
+    @staticmethod
+    def post_process_tasks(user, db_tasks):
+        pass
+
     @staticmethod
     def add_annotation_fields(body, user, action):
         return body
